@@ -35,7 +35,9 @@ import android.widget.TextView;
 import org.videolan.vlc.PlaybackService;
 import org.videolan.vlc.R;
 import org.videolan.vlc.gui.PlaybackServiceFragment;
+import org.videolan.vlc.gui.helpers.OnRepeatListener;
 import org.videolan.vlc.gui.helpers.UiTools;
+import org.videolan.vlc.media.MediaWrapper;
 import org.videolan.vlc.util.Strings;
 
 public class PlaybackSpeedDialog extends DialogFragment implements PlaybackService.Client.Callback {
@@ -85,6 +87,8 @@ public class PlaybackSpeedDialog extends DialogFragment implements PlaybackServi
         mPlaybackSpeedPlus.setOnClickListener(mSpeedUpListener);
         mPlaybackSpeedMinus.setOnClickListener(mSpeedDownListener);
         mSpeedValue.setOnClickListener(mResetListener);
+        mPlaybackSpeedMinus.setOnTouchListener(new OnRepeatListener(mSpeedDownListener));
+        mPlaybackSpeedPlus.setOnTouchListener(new OnRepeatListener(mSpeedUpListener));
 
         mTextColor = mSpeedValue.getCurrentTextColor();
 
@@ -112,7 +116,7 @@ public class PlaybackSpeedDialog extends DialogFragment implements PlaybackServi
                 return;
             if (fromUser) {
                 float rate = (float) Math.pow(4, ((double) progress / (double) 100) - 1);
-                mService.setRate(rate);
+                mService.setRate(rate, mService.getCurrentMediaWrapper().getType() == MediaWrapper.TYPE_AUDIO);
                 updateInterface();
             }
         }
@@ -133,7 +137,7 @@ public class PlaybackSpeedDialog extends DialogFragment implements PlaybackServi
             if (mService.getRate() == 1.0d)
                 return;
 
-            mService.setRate(1);
+            mService.setRate(1F, mService.getCurrentMediaWrapper().getType() == MediaWrapper.TYPE_AUDIO);
             setRateProgress();
         }
     };
@@ -167,7 +171,7 @@ public class PlaybackSpeedDialog extends DialogFragment implements PlaybackServi
         float rate = Math.round((initialRate + delta) * 100f) / 100f;
         if (rate < 0.25f || rate > 4f)
             return;
-        mService.setRate(rate);
+        mService.setRate(rate, mService.getCurrentMediaWrapper().getType() == MediaWrapper.TYPE_AUDIO);
     }
 
     private void updateInterface() {
